﻿## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.
    
init -1 python hide:

    ## Should we enable the use of developer tools? This should be
    ## set to False before the game is released, so the user can't
    ## cheat using developer tools.

    config.developer = True

    ## These control the width and height of the screen.

    config.screen_width = 800
    config.screen_height = 600

    ## This controls the title of the window, when Ren'Py is
    ## running in a window.

    config.window_title = "Caught in between A childhood prologue"
    config.help = "None"

    #########################################
    # Layouts
    
    ## This enables the use of an in-game menu that is made out of
    ## buttons.

    layout.button_menu()
 
  
        
    

    #########################################
    # Themes
    
    ## We then want to call a theme function. themes.roundrect is
    ## a theme that features the use of rounded rectangles. It's
    ## the only theme we currently support.
    ##
    ## The theme function takes a number of parameters that can
    ## customize the color scheme.
    theme.glow(
                                    
        ## The color of an idle widget face.
        widget = "#93F3F7",

        ## The color of a focused widget face.
        widget_hover = "#73F3F7",

        ## The color of the text in a widget.
        widget_text = "#000000",

        ## The color of the text in a selected widget. (For
        ## example, the current value of a preference.)
        widget_selected = "#000000",

        ## The color of a disabled widget face. 
        disabled = "#FFFFFF",

        ## The color of disabled widget text.
        disabled_text = "#FFFFFF",

        ## The color of informational labels.
        label = "#8C8C8C",

        ## The color of a frame containing widgets.
        frame = "#FFFFFF",

        ## The background of the main menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        mm_root = "mainmenu.png",

        ## The background of the game menu. This can be a color
        ## beginning with '#', or an image filename. The latter
        ## should take up the full height and width of the screen.
        gm_root = "mainmenu.png",

        ## If this is True, the in-game window is rounded. If False,
        ## the in-game window is square.
        rounded_window = True,

        ## And we're done with the theme. The theme will customize
        ## various styles, so if we want to change them, we should
        ## do so below.            
        )


    #########################################
    ## These settings let you customize the window containing the
    ## dialogue and narration, by replacing it with an image.

    ## The background of the window. In a Frame, the two numbers
    ## are the size of the left/right and top/bottom borders,
    ## respectively.

    style.window.background = Frame("window.png", 13,13)
    style.say_who_window.background = Frame("window.png", 12, 12)
    style.say_label.xanchor = 110
    style.say_label.size = 20
 

    ## Margin is space surrounding the window, where the background
    ## is not drawn.

    style.window.left_margin = 6
    style.window.right_margin = 6
    style.window.top_margin = 6
    style.window.bottom_margin = 6

    ## Padding is space inside the window, where the background is
    ## drawn.

    style.window.left_padding = 6
    style.window.right_padding = 6
    style.window.top_padding = 6
    style.window.bottom_padding = 6
    
    

    ## This is the minimum height of the window, including the margins
    ## and padding.

    #style.window.yminimum = 250
    


    #########################################
    ## This lets you change the placement of the main menu.

    ## The way placement works is that we find an anchor point
    ## inside a displayable, and a position (pos) point on the
    ## screen. We then place the displayable so the two points are
    ## at the same place.

    ## An anchor/pos can be given as an integer or a floating point
    ## number. If an integer, the number is interpreted as a number
    ## of pixels from the upper-left corner. If a floating point,
    ## the number is interpreted as a fraction of the size of the
    ## displayable or screen.

    #style.mm_menu_frame.xpos = 1
    #style.mm_menu_frame.xanchor = 1
    #style.mm_menu_frame.ypos = 1
    #style.mm_menu_frame.yanchor = 1
    #style.mm_menu_frame.yalign = 2
    #style.mm_menu_frame.xalign = 2
    
   

    #########################################
    ## These let you customize the default font used for text in Ren'Py.

    ## The file containing the default font.

    style.default.font = "CHERI___.TTF"
    style.default.bold = False
    style.default.color = "#8c8c8c"

    ## The default size of text.

    style.default.size = 19
   


    ## Note that these only change the size of some of the text. Other
    ## buttons have their own styles.


    #########################################
    ## These settings let you change some of the sounds that are used by
    ## Ren'Py.

    ## Set this to False if the game does not have any sound effects.

    config.has_sound = True

    ## Set this to False if the game does not have any music.

    config.has_music = True

    ## Set this to False if the game does not have voicing.

    config.has_voice = False

    ## Sounds that are used when button and imagemaps are clicked.

    style.button.activate_sound = "click.wav"
    style.imagemap.activate_sound = "click.wav"

    ## Sounds that are used when entering and exiting the game menu.

    config.enter_sound = "click.wav"
    config.exit_sound = "click.wav"

    ## A sample sound that can be played to check the sound volume.

    config.sample_sound = "click.wav"

    ## Music that is played while the user is at the main menu.

    config.main_menu_music = "nostalgia.mp3"


    #########################################
    ## Help.

    ## This lets you configure the help option on the Ren'Py menus.
    ## It may be:
    ## - A label in the script, in which case that label is called to
    ##   show help to the user.
    ## - A file name relative to the base directory, which is opened in a
    ##   web browser.
    ## - None, to disable help.   
    config.help = "README.html"


    #########################################
    ## Transitions.

    ## Used when entering the game menu from the game.
    config.enter_transition = Dissolve(.5) 

    ## Used when exiting the game menu to the game.
    config.exit_transition = Dissolve(.5)

    ## Used between screens of the game menu.
    config.intra_transition = Dissolve(.5)

    ## Used when entering the game menu from the main menu.
    config.main_game_transition = Dissolve(.5)

    ## Used when returning to the main menu from the game.
    config.game_main_transition = Dissolve(.5)

    ## Used when entering the main menu from the splashscreen.
    config.end_splash_transition = Dissolve(.5)

    ## Used when entering the main menu after the game has ended.
    config.end_game_transition = Dissolve(.5)

    ## Used when a game is loaded.
    config.after_load_transition = None

    ## Used when the window is shown.
    config.window_show_transition = None

    ## Used when the window is hidden.
    config.window_hide_transition = None


    #########################################
    ## This is the name of the directory where the game's data is
    ## stored. (It needs to be set early, before any other init code
    ## is run, so the persisten information can be found by the init code.)
python early:
    config.save_directory = "Caught in Between A childhood prologue-1297762552"

init -1 python hide:
    #########################################
    ## Default values of Preferences.

    ## Note: These options are only evaluated the first time a
    ## game is run. To have them run a second time, delete
    ## game/saves/persistent

    ## Should we start in fullscreen mode?

    config.default_fullscreen = False

    ## The default text speed in characters per second. 0 is infinite.

    config.default_text_cps = 25

    #########################################
    ## More customizations can go here."
label main_menu:
    scene mainmenu

    $ ui.hbox(xpos=0.0, ypos=0.85)
    $ ui.imagebutton("start game.png", "Start game hover.png", clicked=ui.returns("start"))
    $ ui.imagebutton("load game.png", "load game hover.png", clicked=ui.returns("load"))
    $ ui.imagebutton("options.png", "Options hover.png", clicked=ui.returns("prefs"))
    $ ui.imagebutton("quit.png", "quit hover.png", clicked=ui.returns("quit"))
    $ ui.close()
    
    $ result = ui.interact()
    
    if result == "start":
        hide mainmenu
        $ renpy.jump_out_of_context("start")
        
        
    elif result == "load":
        jump load_screen
        
    elif result == "prefs":
        jump preferences_screen
            
    elif result == "quit":
        $ renpy.quit()

    return
    
    
    
    
init python:

    # The color of a menu choice when it isn't hovered.
    style.nvl_menu_choice.idle_color = "#ccccccff"

    # The color of a menu choice when it is hovered.
    style.nvl_menu_choice.hover_color = "#ffffffff"

    # The color of the background of a menu choice, when it isn't
    # hovered.
    style.nvl_menu_choice_button.idle_background = "#00000000"

    # The color of the background of a menu choice, when it is
    # hovered.
    style.nvl_menu_choice_button.hover_background = "#ff000044"

    # How far from the left menu choices should be indented.
    style.nvl_menu_choice_button.left_margin = 20

    
    style.nvl_window.background = "nvl_window.png"
    style.nvl_window.xpadding = 55
    style.nvl_window.ypadding = 55

    config.empty_window = nvl_show_core
    config.window_hide_transition = dissolve
    config.window_show_transition = dissolve
    
    config.game_menu = [
        ( "return", u"Return", ui.jumps("_return"), 'True'),
        ( "main", u"Main Menu", ui.callsinnewcontext("_main_menu_prompt"), 'not main_menu' ),
        ( "save", u"Save Game", _intra_jumps("save_screen", "intra_transition"), 'not main_menu' ),
        ( "load", u"Load Game", _intra_jumps("load_screen", "intra_transition"), 'True'),
        ( "preferences", u"Preferences", _intra_jumps("preferences_screen", "intra_transition"), 'True' ),
         ( "quit", u"Quit", ui.callsinnewcontext("_quit_prompt"), 'True' )
        ]

        
    
    config.window_icon = "icon.PNG"
 


